@@ -31,8 +31,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // KDE
 #include <QFileDialog>
 #include <KColorScheme>
-#include <KIO/StatJob>
-#include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -359,23 +357,6 @@ void GvCore::saveAs(const QUrl &url)
         return;
     }
 
-    // Check for overwrite
-    KIO::StatJob *statJob = KIO::stat(saveAsUrl, KIO::StatJob::DestinationSide, 0);
-    KJobWidgets::setWindow(statJob, d->mMainWindow);
-    if (statJob->exec()) {
-        int answer = KMessageBox::warningContinueCancel(
-                         d->mMainWindow,
-                         xi18nc("@info",
-                                "A file named <filename>%1</filename> already exists.\n"
-                                "Are you sure you want to overwrite it?",
-                                saveAsUrl.fileName()),
-                         QString(),
-                         KStandardGuiItem::overwrite());
-        if (answer == KMessageBox::Cancel) {
-            return;
-        }
-    }
-
     // Start save
     Document::Ptr doc = DocumentFactory::instance()->load(url);
     KJob* job = doc->save(saveAsUrl, format.data());
@@ -405,7 +386,7 @@ void GvCore::slotSaveResult(KJob* _job)
     if (job->error()) {
         QString name = newUrl.fileName().isEmpty() ? newUrl.toDisplayString() : newUrl.fileName();
         QString msg = xi18nc("@info", "<b>Saving <filename>%1</filename> failed:</b><br />%2",
-                             name, job->errorString());
+                             name, kxi18n(qPrintable(job->errorString())));
 
         int result = KMessageBox::warningContinueCancel(
                          d->mMainWindow, msg,
@@ -413,7 +394,7 @@ void GvCore::slotSaveResult(KJob* _job)
                          KStandardGuiItem::saveAs());
 
         if (result == KMessageBox::Continue) {
-            saveAs(newUrl);
+            saveAs(oldUrl);
         }
         return;
     }
