@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QListView>
 
 // KDE
-#include <KUrl>
+#include <QUrl>
 
 class KFileItem;
 class QDragEnterEvent;
@@ -96,7 +96,7 @@ public:
      */
     bool isBusy(const QModelIndex& index) const;
 
-    virtual void setModel(QAbstractItemModel* model);
+    virtual void setModel(QAbstractItemModel* model) Q_DECL_OVERRIDE;
 
     void setThumbnailProvider(ThumbnailProvider* thumbnailProvider);
 
@@ -123,7 +123,7 @@ Q_SIGNALS:
      * signal replaces it.
      */
     void indexActivated(const QModelIndex&);
-    void urlListDropped(const KUrl::List& lst, const KUrl& destination);
+    void urlListDropped(const QList<QUrl>& lst, const QUrl &destination);
 
     void thumbnailSizeChanged(const QSize&);
     void thumbnailWidthChanged(int);
@@ -158,29 +158,30 @@ public Q_SLOTS:
     void generateThumbnailsForItems();
 
 protected:
-    virtual void dragEnterEvent(QDragEnterEvent*);
+    virtual void dragEnterEvent(QDragEnterEvent*) Q_DECL_OVERRIDE;
 
-    virtual void dragMoveEvent(QDragMoveEvent*);
+    virtual void dragMoveEvent(QDragMoveEvent*) Q_DECL_OVERRIDE;
 
-    virtual void dropEvent(QDropEvent*);
+    virtual void dropEvent(QDropEvent*) Q_DECL_OVERRIDE;
 
-    virtual void keyPressEvent(QKeyEvent*);
+    virtual void keyPressEvent(QKeyEvent*) Q_DECL_OVERRIDE;
 
-    virtual void resizeEvent(QResizeEvent*);
+    virtual void resizeEvent(QResizeEvent*) Q_DECL_OVERRIDE;
 
-    virtual void scrollContentsBy(int dx, int dy);
+    virtual void scrollContentsBy(int dx, int dy) Q_DECL_OVERRIDE;
 
-    virtual void showEvent(QShowEvent*);
+    virtual void showEvent(QShowEvent*) Q_DECL_OVERRIDE;
 
-    virtual void wheelEvent(QWheelEvent*);
+    virtual void wheelEvent(QWheelEvent*) Q_DECL_OVERRIDE;
 
-    virtual void startDrag(Qt::DropActions);
+    virtual void startDrag(Qt::DropActions) Q_DECL_OVERRIDE;
 
 protected Q_SLOTS:
-    virtual void rowsAboutToBeRemoved(const QModelIndex& parent, int start, int end);
-    virtual void rowsInserted(const QModelIndex& parent, int start, int end);
-    virtual void selectionChanged(const QItemSelection& selected, const QItemSelection& deselected);
-    virtual void dataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight);
+    virtual void rowsAboutToBeRemoved(const QModelIndex& parent, int start, int end) Q_DECL_OVERRIDE;
+    virtual void rowsInserted(const QModelIndex& parent, int start, int end) Q_DECL_OVERRIDE;
+    virtual void selectionChanged(const QItemSelection& selected, const QItemSelection& deselected) Q_DECL_OVERRIDE;
+    virtual void dataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight,
+                             const QVector<int> &roles = QVector<int>()) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void showContextMenu();
@@ -189,14 +190,14 @@ private Q_SLOTS:
     void setBrokenThumbnail(const KFileItem&);
 
     /**
-     * Generate thumbnail for @a index.
+     * Generate thumbnail for url.
      */
-    void updateThumbnail(const QModelIndex& index);
+    void updateThumbnail(const QUrl& url);
 
     /**
-     * Tells the view the busy state of the document pointed by the index has changed.
+     * Tells the view the busy state of the document pointed by the url has changed.
      */
-    void updateThumbnailBusyState(const QModelIndex& index, bool);
+    void updateThumbnailBusyState(const QUrl& url, bool);
 
     /*
      * Cause a repaint of all busy indexes
