@@ -17,16 +17,16 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include <qtest_kde.h>
+#include <qtest.h>
 
-#include "imagescalertest.moc"
+#include "imagescalertest.h"
 
 #include "../lib/imagescaler.h"
 #include "../lib/document/documentfactory.h"
 
 #include "testutils.h"
 
-QTEST_KDEMAIN(ImageScalerTest, GUI)
+QTEST_MAIN(ImageScalerTest)
 
 using namespace Gwenview;
 
@@ -36,7 +36,7 @@ using namespace Gwenview;
 void ImageScalerTest::testScaleFullImage()
 {
     const qreal zoom = 2;
-    KUrl url = urlForTestFile("test.png");
+    QUrl url = urlForTestFile("test.png");
     Document::Ptr doc = DocumentFactory::instance()->load(url);
 
     // Wait for meta info because we need the document size
@@ -51,7 +51,9 @@ void ImageScalerTest::testScaleFullImage()
 
     scaler.setDestinationRegion(QRect(QPoint(0, 0), doc->size() * zoom));
 
-    bool ok = QTest::kWaitForSignal(&scaler, SIGNAL(scaledRect(int,int,QImage)), 30);
+    QSignalSpy spy(&scaler, SIGNAL(scaledRect(int,int,QImage)));
+
+    bool ok = spy.wait(30);
     QVERIFY2(ok, "ImageScaler did not emit scaledRect() signal in time");
 
     // Document should be fully loaded by the time image scaler is done
